@@ -3,7 +3,7 @@ import sys
 import os
 
 # comtypes version numbers follow semver (http://semver.org/) and PEP 440
-__version__ = "1.1.4"
+__version__ = "1.1.6"
 
 import logging
 class NullHandler(logging.Handler):
@@ -378,7 +378,7 @@ class _cominterface_meta(type):
 
                     try:
                         result = self.Item(*args)
-                    except COMError as err:
+                    except COMError, err:
                         (hresult, text, details) = err.args
                         if hresult == -2147352565:  # DISP_E_BADINDEX
                             raise IndexError("invalid index")
@@ -397,7 +397,7 @@ class _cominterface_meta(type):
                     "Attempt 'self.Item[index] = value'"
                     try:
                         self.Item[index] = value
-                    except COMError as err:
+                    except COMError, err:
                         (hresult, text, details) = err.args
                         if hresult == -2147352565:  # DISP_E_BADINDEX
                             raise IndexError("invalid index")
@@ -494,7 +494,7 @@ class _cominterface_meta(type):
                 if is_prop:
                     self.__map_case__[name[5:].lower()] = name[5:]
 
-        for (name, nargs), methods in list(properties.items()):
+        for (name, nargs), methods in properties.items():
             # methods contains [propget or None, propput or None, propputref or None]
             if methods[1] is not None and methods[2] is not None:
                 # both propput and propputref.
@@ -580,7 +580,7 @@ class _cominterface_meta(type):
             for itf in self.mro()[1:-1]:
                 result += len(itf.__dict__["_methods_"])
             return result
-        except KeyError as err:
+        except KeyError, err:
             (name,) = err.args
             if name == "_methods_":
                 raise TypeError("baseinterface '%s' has no _methods_" % itf.__name__)
@@ -661,7 +661,7 @@ class _cominterface_meta(type):
                 return rescode
 
             rescode = list(rescode)
-            for outnum, o in list(outargs.items()):
+            for outnum, o in outargs.items():
                 rescode[outnum] = o.__ctypes_from_outparam__()
             return rescode
         return call_with_inout
@@ -785,7 +785,7 @@ class _cominterface_meta(type):
                     self.__map_case__[name[5:].lower()] = name[5:]
 
         # create public properties / attribute accessors
-        for (name, doc, nargs), methods in list(properties.items()):
+        for (name, doc, nargs), methods in properties.items():
             # methods contains [propget or None, propput or None, propputref or None]
             if methods[1] is not None and methods[2] is not None:
                 # both propput and propputref.
@@ -901,8 +901,9 @@ class _compointer_meta(type(c_void_p), _cominterface_meta):
     "metaclass for COM interface pointer classes"
     # no functionality, but needed to avoid a metaclass conflict
 
-class _compointer_base(c_void_p, metaclass=_compointer_meta):
+class _compointer_base(c_void_p):
     "base class for COM interface pointer classes"
+    __metaclass__ = _compointer_meta
     def __del__(self, _debug=logger.debug):
         "Release the COM refcount we own."
         if self:
@@ -1022,7 +1023,7 @@ class BSTR(_SimpleCData):
 ################################################################
 # IDL stuff
 
-class helpstring(str):
+class helpstring(unicode):
     "Specifies the helpstring for a COM method or property."
 
 class defaultvalue(object):
@@ -1128,7 +1129,7 @@ def COMMETHOD(idlflags, restype, methodname, *argspec):
 ################################################################
 # IUnknown, the root of all evil...
 
-class IUnknown(object, metaclass=_cominterface_meta):
+class IUnknown(object):
     """The most basic COM interface.
 
     Each subclasses of IUnknown must define these class attributes:
@@ -1141,6 +1142,7 @@ class IUnknown(object, metaclass=_cominterface_meta):
     with STDMETHOD or COMMETHOD calls.
     """
     _case_insensitive_ = False
+    __metaclass__ = _cominterface_meta
     _iid_ = GUID("{00000000-0000-0000-C000-000000000046}")
 
     _methods_ = [
@@ -1206,7 +1208,7 @@ def CoGetObject(displayname, interface):
         interface = IUnknown
     punk = POINTER(interface)()
     # Do we need a way to specify the BIND_OPTS parameter?
-    _ole32.CoGetObject(str(displayname),
+    _ole32.CoGetObject(unicode(displayname),
                        None,
                        byref(interface._iid_),
                        byref(punk))
@@ -1385,6 +1387,6 @@ from comtypes._comobject import COMObject
 
 from comtypes._meta import _coclass_meta
 
-class CoClass(COMObject, metaclass=_coclass_meta):
-    pass
+class CoClass(COMObject):
+    __metaclass__ = _coclass_meta
 ################################################################
